@@ -5,8 +5,10 @@ from .module import Module
 from .sequential import Sequential
 from . import activations as acts
 from . import initializers as inits
-from . import layers, losses
+from . import layers
+from . import losses
 from . import optimizers as optims
+from . import utils
 
 
 def seed(seed):
