@@ -1,6 +1,7 @@
 from .losses import Loss
 from .layers import ParamLayer
 from tabulate import tabulate
+from copy import deepcopy as dc
 
 
 class Sequential:
@@ -33,10 +34,7 @@ class Sequential:
         name, output_shape, n_param = "Input", (None, self._layers[0].input_shape), 0
         data.append((name, output_shape, n_param))
         for i, layer in enumerate(self._layers):
-            if isinstance(layer, ParamLayer):
-                name, output_shape, n_param = layer.summary()
-            else:
-                name, n_param, output_shape = *layer.summary(), output_shape
+            name, output_shape, n_param = layer.summary()
             name += f"[{i}]"
             data.append((name, output_shape, n_param))
 
@@ -49,7 +47,7 @@ class Sequential:
         print(f"total trainable parameters: {total_param}\n")
 
     def set_weights(self, params):
-        self._parameters = params
+        self._parameters = dc(params)
         for i, layer in enumerate(self._layers):
             if isinstance(self._layers[i], ParamLayer):
                 self._layers[i].vars = self._parameters[i]
